@@ -9,6 +9,9 @@ PLUGIN_ID_SOURCE_DICT = 'dict'
 """ ConfigSource plugin_id for the configerus dict configsource plugin """
 
 
+CONFIGERUS_DICT_DATA_KEY = 'data'
+""" if you load paths from config, this is the key that should give the path """
+
 @SourceFactory(plugin_id=PLUGIN_ID_SOURCE_DICT)
 def plugin_factory_configsource_dict(config: Config, instance_id: str = ''):
     """ create an configsource dict plugin """
