@@ -17,6 +17,7 @@ import unittest
 
 import configerus
 from configerus.loaded import LOADED_KEY_ROOT
+from configerus.contrib.env import PLUGIN_ID_SOURCE_ENV
 from configerus.contrib.dict import PLUGIN_ID_SOURCE_DICT
 from configerus.contrib.files import PLUGIN_ID_SOURCE_PATH
 
@@ -119,9 +120,21 @@ config_sources = [
             },
             'config.yaml': {
                 '5': "seventh 5 yaml",
-                '6': "seventh 6 yaml"
+                '6': "seventh 6 yaml",
+                '7': {
+                    '1': ['1']
+                }
             }
         }
+    },
+    {
+        'name': 'eighth',
+        'priority': 85,
+        'type': PLUGIN_ID_SOURCE_ENV,
+        'data': {
+            'env_one': "env eighth env one",
+            'env_two_one': "env eighth env two.one",
+        }
     }
 ]
 """ Contents of test config files used as the source for a config object """
@@ -154,6 +167,13 @@ class ConfigBehaviour(unittest.TestCase):
     def tearDownClass(cls):
         test_config_cleanup(cls.config)
 
+    def test_source_env_basic(self):
+        """ test the env source basically """
+        all_env = self.config.load('env')
+        self.assertIsNotNone(all_env.get('one'))
+        self.assertEqual(all_env.get('one'), "env eighth env one")
+        self.assertEqual(all_env.get('two.one'), "env eighth env two.one")
+
     def test_basic_combined(self):
         """ test some basic file combining by the config object """
 
@@ -173,7 +193,7 @@ class ConfigBehaviour(unittest.TestCase):
         self.assertEqual(self.loaded_config.get('5'), "seventh 5 json")
 
     def test_get_multiple_keys(self):
-        """ test the the loaded config base value functions """
+        """ test the the loaded get of various key formats """
 
         third_3_base = self.loaded_config.get('3')
         third_3_2 = self.loaded_config.get('3.2')
